@echo off
SETLOCAL ENABLEDELAYEDEXPANSION

REM * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *
REM *                                                                         *
REM *  IBM (R) CheckFibrePrerequisites.cmd                                    *
REM *                                                                         *
REM * Description: Checks for Fibre Channel HBAs prerequisites                *
REM *                                                                         *
REM * Copyright 2008-2009.  All rights reserved.                              *
REM *                                                                         *
REM * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *

REM * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *
REM *                             Initialize                                  *
REM * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *
:Main

SET RC=0
SET RMSG=
SET ERROR_COUNT=0
SET LAST_VAR_SETTING_FAILURE_MSG="No variable setting error(s) detected"

IF /I "%TK_Flag_CheckedFibrePrerequisites%" == "Yes" (

	SET TK_Flag_CheckedFibrePrerequisites=No
	GOTO EndOfScript
)

REM * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *
REM *               CHECK FOR FIBRE PREREQUISITES                             *
REM * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *

Lecho "%%t " /F /SN
Lecho "[%0] " /F /SN /LO
Lecho "- Checking FIBRE Prerequisites...\n" /F

REM * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *
REM *        Let's create the list of all the TK_FIBRE_* variables            *
REM * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *
:CreateListOfTK_FIBRE_ENVs

FOR /F "tokens=*" %%A IN ('SET TK_FIBRE_') DO (

	SET __TK_FIBRE_PARAM_NAMES.%%A
)

REM * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *
REM *          Let's get the number of HBAs to configure                      *
REM * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *
:GetNumberOfHBAsToConfigure

REM /*--- Default HBAs to configure is 1. ---*/
SET NUMBER_OF_HBAS_TO_CONFIGURE=Unset
FOR /F "tokens=2* delims=.=" %%A IN ('SET __TK_FIBRE_PARAM_NAMES.') DO (

	IF /I "%%A" == "TK_FIBRE_COUNT" (

		SET NUMBER_OF_HBAS_TO_CONFIGURE=%%B
	)
)

REM /*--- If the TK_FIBRE_COUNT was not set. ---*/
IF /I "%NUMBER_OF_HBAS_TO_CONFIGURE%" == "Unset" (

	REM /*--- Increment error count. ---*/
	SET /A ERROR_COUNT+=1

	REM /*--- Let's set the message to be displayed/logged. ---*/
	SET RMSG="<<< [ %0 ] - ERROR: You must set TK_FIBRE_COUNT (number of HBA Ports to configure) to a value.  Format is: TK_FIBRE_COUNT=<Number of HBA Ports to Configure>.  Total errors detected: !ERROR_COUNT!. >>>"

	REM /*--- Let's set the command to be executed. ---*/
	SET Command=Lecho "\n%%t !RMSG:~1,-1!\n" /F

	!Command!

	GOTO Error_LD
)

REM /*--- If the TK_FIBRE_COUNT was set to zero. ---*/
IF /I "%NUMBER_OF_HBAS_TO_CONFIGURE%" == "0" (

	REM /*--- Increment error count. ---*/
	SET /A ERROR_COUNT+=1

	REM /*--- Let's set the message to be returned. ---*/
	SET RMSG="<<< [ %0 ] - ERROR: You must set TK_FIBRE_COUNT (number of HBA Ports to configure) to a value greater than zero.  Format is: TK_FIBRE_COUNT=<Number of HBA Ports to Configure>.  Total errors detected: !ERROR_COUNT!. >>>"

	REM /*--- Let's set the command to be executed. ---*/
	SET Command=Lecho "\n%%t !RMSG:~1,-1!\n" /F

	!Command!

	GOTO Error_LD
)

REM * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *
REM *                    Let's now configure each HBA                         *
REM * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *
:ConfigureHBAs

SET HBA_NUMBER=0
SET ERROR_COUNT=0
:Loop

	SET HBA_ID=Unset
	SET DISABLE_BOOT_DEVICES=0
	SET DISABLE_BOOT_PRIM_DEVICE=Unset
	SET DISABLE_BOOT_ALT1_DEVICE=Unset
	SET DISABLE_BOOT_ALT2_DEVICE=Unset
	SET DISABLE_BOOT_ALT3_DEVICE=Unset
	SET ENABLE_BOOT_PRIM_DEVICE_TARGET_WWNN=Unset
	SET ENABLE_BOOT_PRIM_DEVICE_TARGET_WWPN=Unset
	SET ENABLE_BOOT_PRIM_DEVICE_TARGET_LUNID=Unset
	SET ENABLE_BOOT_ALT1_DEVICE_TARGET_WWNN=Unset
	SET ENABLE_BOOT_ALT1_DEVICE_TARGET_WWPN=Unset
	SET ENABLE_BOOT_ALT1_DEVICE_TARGET_LUNID=Unset
	SET ENABLE_BOOT_ALT2_DEVICE_TARGET_WWNN=Unset
	SET ENABLE_BOOT_ALT2_DEVICE_TARGET_WWPN=Unset
	SET ENABLE_BOOT_ALT2_DEVICE_TARGET_LUNID=Unset
	SET ENABLE_BOOT_ALT3_DEVICE_TARGET_WWNN=Unset
	SET ENABLE_BOOT_ALT3_DEVICE_TARGET_WWPN=Unset
	SET ENABLE_BOOT_ALT3_DEVICE_TARGET_LUNID=Unset

	REM /*--- Increment the HBA Number. ---*/
	SET /A HBA_NUMBER+=1

	REM /*--- Let's go through the list. ---*/
	FOR /F "tokens=2* delims=.=" %%A IN ('SET __TK_FIBRE_PARAM_NAMES.TK_FIBRE_!HBA_NUMBER!') DO (


		IF /I "%%A" == "TK_FIBRE_!HBA_NUMBER!_HBA_ID" (

			REM /*--- Let's set the HBA ID ---*/
			SET HBA_ID=%%B

		)

		IF /I "%%A" == "TK_FIBRE_!HBA_NUMBER!_BOOT_DISABLE" (

			FOR %%I IN (%%B) DO (

				IF /I "%%I" == "All" (

					REM /*--- Let's set the flag to true. ---*/
					SET DISABLE_BOOT_DEVICES=1

					REM /*--- Let's add the appropriate parameter values. ---*/
					SET DISABLE_BOOT_PRIM_DEVICE=prim
					SET DISABLE_BOOT_ALT1_DEVICE=alt1
					SET DISABLE_BOOT_ALT2_DEVICE=alt2
					SET DISABLE_BOOT_ALT3_DEVICE=alt3
				)

				IF /I "%%I" == "Prim" (

					REM /*--- Let's set the flag to true. ---*/
					SET DISABLE_BOOT_DEVICES=1

					REM /*--- Let's add the appropriate parameter value. ---*/
					SET DISABLE_BOOT_PRIM_DEVICE=prim
				)

				IF /I "%%I" == "Alt1" (

					REM /*--- Let's set the flag to true. ---*/
					SET DISABLE_BOOT_DEVICES=1

					REM /*--- Let's add the appropriate parameter value. ---*/
					SET DISABLE_BOOT_ALT1_DEVICE=alt1
				)

				IF /I "%%I" == "Alt2" (

					REM /*--- Let's set the flag to true. ---*/
					SET DISABLE_BOOT_DEVICES=1

					REM /*--- Let's add the appropriate parameter value. ---*/
					SET DISABLE_BOOT_ALT2_DEVICE=alt2
				)

				IF /I "%%I" == "Alt3" (

					REM /*--- Let's set the flag to true. ---*/
					SET DISABLE_BOOT_DEVICES=1

					REM /*--- Let's add the appropriate parameter value. ---*/
					SET DISABLE_BOOT_ALT3_DEVICE=alt3
				)

				IF /I "%%I" == "No" (

					REM /*--- Let's set the flag to false. ---*/
					SET DISABLE_BOOT_DEVICES=0

					REM /*--- Let's add the appropriate parameter values. ---*/
					SET DISABLE_BOOT_PRIM_DEVICE=Unset
					SET DISABLE_BOOT_ALT1_DEVICE=Unset
					SET DISABLE_BOOT_ALT2_DEVICE=Unset
					SET DISABLE_BOOT_ALT3_DEVICE=Unset
				)
			)
		)

		IF /I "%%A" == "TK_FIBRE_!HBA_NUMBER!_BOOT_PRIM" (

			IF /I NOT "!DISABLE_BOOT_PRIM_DEVICE!" == "prim" (

				SET ENABLE_BOOT_PRIM_COUNT=1
				FOR %%I IN (%%B) DO (

					REM /*--- We are expecting first parameter to be "WWNN" ---*/
					IF "!ENABLE_BOOT_PRIM_COUNT!" == "1" SET ENABLE_BOOT_PRIM_DEVICE_TARGET_WWNN=%%I

					REM /*--- We are expecting second parameter to be "WWPN" ---*/
					IF "!ENABLE_BOOT_PRIM_COUNT!" == "2" SET ENABLE_BOOT_PRIM_DEVICE_TARGET_WWPN=%%I

					REM /*--- We are expecting third parameter to be "LUN ID" ---*/
					IF "!ENABLE_BOOT_PRIM_COUNT!" == "3" SET ENABLE_BOOT_PRIM_DEVICE_TARGET_LUNID=%%I

					REM /*--- Increment counter. ---*/
					SET /A ENABLE_BOOT_PRIM_COUNT+=1
				)
			)
		)

		IF /I "%%A" == "TK_FIBRE_!HBA_NUMBER!_BOOT_ALT1" (

			IF /I NOT "!DISABLE_BOOT_ALT1_DEVICE!" == "alt1" (

				SET ENABLE_BOOT_ALT1_COUNT=1
				FOR %%I IN (%%B) DO (

					REM /*--- We are expecting first parameter to be "WWNN" ---*/
					IF "!ENABLE_BOOT_ALT1_COUNT!" == "1" SET ENABLE_BOOT_ALT1_DEVICE_TARGET_WWNN=%%I

					REM /*--- We are expecting second parameter to be "WWPN" ---*/
					IF "!ENABLE_BOOT_ALT1_COUNT!" == "2" SET ENABLE_BOOT_ALT1_DEVICE_TARGET_WWPN=%%I

					REM /*--- We are expecting third parameter to be "LUN ID" ---*/
					IF "!ENABLE_BOOT_ALT1_COUNT!" == "3" SET ENABLE_BOOT_ALT1_DEVICE_TARGET_LUNID=%%I

					REM /*--- Increment counter. ---*/
					SET /A ENABLE_BOOT_ALT1_COUNT+=1
				)
			)
		)

		IF /I "%%A" == "TK_FIBRE_!HBA_NUMBER!_BOOT_ALT2" (

			IF /I NOT "!DISABLE_BOOT_ALT2_DEVICE!" == "alt2" (

				SET ENABLE_BOOT_ALT2_COUNT=1
				FOR %%I IN (%%B) DO (

					REM /*--- We are expecting first parameter to be "WWNN" ---*/
					IF "!ENABLE_BOOT_ALT2_COUNT!" == "1" SET ENABLE_BOOT_ALT2_DEVICE_TARGET_WWNN=%%I

					REM /*--- We are expecting second parameter to be "WWPN" ---*/
					IF "!ENABLE_BOOT_ALT2_COUNT!" == "2" SET ENABLE_BOOT_ALT2_DEVICE_TARGET_WWPN=%%I

					REM /*--- We are expecting third parameter to be "LUN ID" ---*/
					IF "!ENABLE_BOOT_ALT2_COUNT!" == "3" SET ENABLE_BOOT_ALT2_DEVICE_TARGET_LUNID=%%I

					REM /*--- Increment counter. ---*/
					SET /A ENABLE_BOOT_ALT2_COUNT+=1
				)
			)
		)

		IF /I "%%A" == "TK_FIBRE_!HBA_NUMBER!_BOOT_ALT3" (

			IF /I NOT "!DISABLE_BOOT_ALT3_DEVICE!" == "alt3" (

				SET ENABLE_BOOT_ALT3_COUNT=1
				FOR %%I IN (%%B) DO (

					REM /*--- We are expecting first parameter to be "WWNN" ---*/
					IF "!ENABLE_BOOT_ALT3_COUNT!" == "1" SET ENABLE_BOOT_ALT3_DEVICE_TARGET_WWNN=%%I

					REM /*--- We are expecting second parameter to be "WWPN" ---*/
					IF "!ENABLE_BOOT_ALT3_COUNT!" == "2" SET ENABLE_BOOT_ALT3_DEVICE_TARGET_WWPN=%%I

					REM /*--- We are expecting third parameter to be "LUN ID" ---*/
					IF "!ENABLE_BOOT_ALT3_COUNT!" == "3" SET ENABLE_BOOT_ALT3_DEVICE_TARGET_LUNID=%%I

					REM /*--- Increment counter. ---*/
					SET /A ENABLE_BOOT_ALT3_COUNT+=1
				)
			)
		)
	)


	IF /I "!HBA_ID!" == "Unset" (

		REM /*--- Increment error counter. ---*/
		SET /A ERROR_COUNT+=1

		REM /*--- Set the last variable setting failure error message. ---*/
		SET LAST_VAR_SETTING_FAILURE_MSG="<<< [ %0 ] - ERROR: Missing <hba instance> or <hba wwpn> value for TK_FIBRE_!HBA_NUMBER!_HBA_ID.  Format is: TK_FIBRE_!HBA_NUMBER!_HBA_ID=<hba instance> or <hba wwpn>. >>>"

		REM /*--- Let's set the message to be returned. ---*/
		SET Command=Lecho "%%t !LAST_VAR_SETTING_FAILURE_MSG:~1,-1!\n" /F

		!Command!
	)

	REM /*--- Let's find out if we need to enable the 'prim' boot device setting. ---*/	
	SET ALREADY_EXECUTED=0

	REM /*--- Let's find out if it need to be configure boot from the first target the BIOS finds ---*/
	IF /I "!ENABLE_BOOT_PRIM_DEVICE_TARGET_WWNN!" == "0" (

		IF /I "!ENABLE_BOOT_PRIM_DEVICE_TARGET_WWPN!" == "0" (

			IF /I "!ENABLE_BOOT_PRIM_DEVICE_TARGET_LUNID!" == "0" (

				REM /*--- Let's reset the flag to executed. ---*/
				SET ALREADY_EXECUTED=1
			)
		)
	)

	IF /I "!ALREADY_EXECUTED!" == "0" (

		REM /*--- Let's find out if the "WWNN" parameter value was set. ---*/
		IF /I NOT "!ENABLE_BOOT_PRIM_DEVICE_TARGET_WWNN!" == "Unset" (

			REM /*--- Let's find out if the "WWPN" parameter value was set. ---*/
			IF /I NOT "!ENABLE_BOOT_PRIM_DEVICE_TARGET_WWPN!" == "Unset" (

				REM /*--- Let's find out if the "LUN ID" parameter value was set. ---*/
				IF /I "!ENABLE_BOOT_PRIM_DEVICE_TARGET_LUNID!" == "Unset" (

					REM /*--- Increment error counter. ---*/
					SET /A ERROR_COUNT+=1

					REM /*--- Set the last variable setting failure error message. ---*/
					SET LAST_VAR_SETTING_FAILURE_MSG="<<< [ %0 ] - ERROR: Missing <lun id> value for TK_FIBRE_!HBA_NUMBER!_BOOT_PRIM.  Format is: TK_FIBRE_!HBA_NUMBER!_BOOT_PRIM=<target wwnn> <target wwpn> <lun id>. >>>"

					REM /*--- Let's set the message to be returned. ---*/
					SET Command=Lecho "%%t !LAST_VAR_SETTING_FAILURE_MSG:~1,-1!\n" /F

					!Command!
				)

			) ELSE (

				REM /*--- Increment error counter. ---*/
				SET /A ERROR_COUNT+=1

				REM /*--- Set the last variable setting failure error message. ---*/
				SET LAST_VAR_SETTING_FAILURE_MSG="<<< [ %0 ] - ERROR: Missing <target wwpn> value for TK_FIBRE_!HBA_NUMBER!_BOOT_PRIM.  Format is: TK_FIBRE_!HBA_NUMBER!_BOOT_PRIM=<target wwnn> <target wwpn> <lun id>. >>>"

				REM /*--- Let's set the message to be returned. ---*/
				SET Command=Lecho "%%t !LAST_VAR_SETTING_FAILURE_MSG:~1,-1!\n" /F

				!Command!
			)
		)
	)

	REM /*--- Let's find out if we need to enable the 'alt1' boot device setting. ---*/	
	SET ALREADY_EXECUTED=0

	REM /*--- Let's find out if it need to be configure boot from the first target the BIOS finds ---*/
	IF /I "!ENABLE_BOOT_ALT1_DEVICE_TARGET_WWNN!" == "0" (

		IF /I "!ENABLE_BOOT_ALT1_DEVICE_TARGET_WWPN!" == "0" (

			IF /I "!ENABLE_BOOT_ALT1_DEVICE_TARGET_LUNID!" == "0" (

				REM /*--- Let's reset the flag to executed. ---*/
				SET ALREADY_EXECUTED=1
			)
		)
	)

	IF /I "!ALREADY_EXECUTED!" == "0" (

		REM /*--- Let's find out if the "WWNN" parameter value was set. ---*/
		IF /I NOT "!ENABLE_BOOT_ALT1_DEVICE_TARGET_WWNN!" == "Unset" (

			REM /*--- Let's find out if the "WWPN" parameter value was set. ---*/
			IF /I NOT "!ENABLE_BOOT_ALT1_DEVICE_TARGET_WWPN!" == "Unset" (

				REM /*--- Let's find out if the "LUN ID" parameter value was set. ---*/
				IF /I "!ENABLE_BOOT_ALT1_DEVICE_TARGET_LUNID!" == "Unset" (

					REM /*--- Increment error counter. ---*/
					SET /A ERROR_COUNT+=1

					REM /*--- Set the last variable setting failure error message. ---*/
					SET LAST_VAR_SETTING_FAILURE_MSG="<<< [ %0 ] - ERROR: Missing <lun id> value for TK_FIBRE_!HBA_NUMBER!_BOOT_ALT1.  Format is: TK_FIBRE_!HBA_NUMBER!_BOOT_ALT1=<target wwnn> <target wwpn> <lun id>. >>>"

					REM /*--- Let's set the message to be returned. ---*/
					SET Command=Lecho "%%t !LAST_VAR_SETTING_FAILURE_MSG:~1,-1!\n" /F

					!Command!
				)

			) ELSE (

				REM /*--- Increment error counter. ---*/
				SET /A ERROR_COUNT+=1

				REM /*--- Set the last variable setting failure error message. ---*/
				SET LAST_VAR_SETTING_FAILURE_MSG="<<< [ %0 ] - ERROR: Missing <target wwpn> value for TK_FIBRE_!HBA_NUMBER!_BOOT_ALT1.  Format is: TK_FIBRE_!HBA_NUMBER!_BOOT_ALT1=<target wwnn> <target wwpn> <lun id>. >>>"

				REM /*--- Let's set the message to be returned. ---*/
				SET Command=Lecho "%%t !LAST_VAR_SETTING_FAILURE_MSG:~1,-1!\n" /F

				!Command!
			)
		)
	)

	REM /*--- Let's find out if we need to enable the 'alt2' boot device setting. ---*/	
	SET ALREADY_EXECUTED=0

	REM /*--- Let's find out if it need to be configure boot from the first target the BIOS finds ---*/
	IF /I "!ENABLE_BOOT_ALT2_DEVICE_TARGET_WWNN!" == "0" (

		IF /I "!ENABLE_BOOT_ALT2_DEVICE_TARGET_WWPN!" == "0" (

			IF /I "!ENABLE_BOOT_ALT2_DEVICE_TARGET_LUNID!" == "0" (

				REM /*--- Let's reset the flag to executed. ---*/
				SET ALREADY_EXECUTED=1
			)
		)
	)

	IF /I "!ALREADY_EXECUTED!" == "0" (

		REM /*--- Let's find out if the "WWNN" parameter value was set. ---*/
		IF /I NOT "!ENABLE_BOOT_ALT2_DEVICE_TARGET_WWNN!" == "Unset" (

			REM /*--- Let's find out if the "WWPN" parameter value was set. ---*/
			IF /I NOT "!ENABLE_BOOT_ALT2_DEVICE_TARGET_WWPN!" == "Unset" (

				REM /*--- Let's find out if the "LUN ID" parameter value was set. ---*/
				IF /I "!ENABLE_BOOT_ALT2_DEVICE_TARGET_LUNID!" == "Unset" (

					REM /*--- Increment error counter. ---*/
					SET /A ERROR_COUNT+=1

					REM /*--- Set the last variable setting failure error message. ---*/
					SET LAST_VAR_SETTING_FAILURE_MSG="<<< [ %0 ] - ERROR: Missing <lun id> value for TK_FIBRE_!HBA_NUMBER!_BOOT_ALT2.  Format is: TK_FIBRE_!HBA_NUMBER!_BOOT_ALT2=<target wwnn> <target wwpn> <lun id>. >>>"

					REM /*--- Let's set the message to be returned. ---*/
					SET Command=Lecho "%%t !LAST_VAR_SETTING_FAILURE_MSG:~1,-1!\n" /F

					!Command!
				)

			) ELSE (

				REM /*--- Increment error counter. ---*/
				SET /A ERROR_COUNT+=1

				REM /*--- Set the last variable setting failure error message. ---*/
				SET LAST_VAR_SETTING_FAILURE_MSG="<<< [ %0 ] - ERROR: Missing <target wwpn> value for TK_FIBRE_!HBA_NUMBER!_BOOT_ALT2.  Format is: TK_FIBRE_!HBA_NUMBER!_BOOT_ALT2=<target wwnn> <target wwpn> <lun id>. >>>"

				REM /*--- Let's set the message to be returned. ---*/
				SET Command=Lecho "%%t !LAST_VAR_SETTING_FAILURE_MSG:~1,-1!\n" /F

				!Command!
			)
		)
	)

	SET ALREADY_EXECUTED=0

	REM /*--- Let's find out if it need to be configure boot from the first target the BIOS finds ---*/
	IF /I "!ENABLE_BOOT_ALT3_DEVICE_TARGET_WWNN!" == "0" (

		IF /I "!ENABLE_BOOT_ALT3_DEVICE_TARGET_WWPN!" == "0" (

			IF /I "!ENABLE_BOOT_ALT3_DEVICE_TARGET_LUNID!" == "0" (

				REM /*--- Let's reset the flag to executed. ---*/
				SET ALREADY_EXECUTED=1
			)
		)
	)

	IF /I "!ALREADY_EXECUTED!" == "0" (

		REM /*--- Let's find out if the "WWNN" parameter value was set. ---*/
		IF /I NOT "!ENABLE_BOOT_ALT3_DEVICE_TARGET_WWNN!" == "Unset" (

			REM /*--- Let's find out if the "WWPN" parameter value was set. ---*/
			IF /I NOT "!ENABLE_BOOT_ALT3_DEVICE_TARGET_WWPN!" == "Unset" (

				REM /*--- Let's find out if the "LUN ID" parameter value was set. ---*/
				IF /I "!ENABLE_BOOT_ALT3_DEVICE_TARGET_LUNID!" == "Unset" (

					REM /*--- Increment error counter. ---*/
					SET /A ERROR_COUNT+=1

					REM /*--- Set the last variable setting failure error message. ---*/
					SET LAST_VAR_SETTING_FAILURE_MSG="<<< [ %0 ] - ERROR: Missing <lun id> value for TK_FIBRE_!HBA_NUMBER!_BOOT_ALT3.  Format is: TK_FIBRE_!HBA_NUMBER!_BOOT_ALT3=<target wwnn> <target wwpn> <lun id>. >>>"

					REM /*--- Let's set the message to be returned. ---*/
					SET Command=Lecho "%%t !LAST_VAR_SETTING_FAILURE_MSG:~1,-1!\n" /F

					!Command!
				)

			) ELSE (

				REM /*--- Increment error counter. ---*/
				SET /A ERROR_COUNT+=1

				REM /*--- Set the last variable setting failure error message. ---*/
				SET LAST_VAR_SETTING_FAILURE_MSG="<<< [ %0 ] - ERROR: Missing <target wwpn> value for TK_FIBRE_!HBA_NUMBER!_BOOT_ALT3.  Format is: TK_FIBRE_!HBA_NUMBER!_BOOT_ALT3=<target wwnn> <target wwpn> <lun id>. >>>"

				REM /*--- Let's set the message to be returned. ---*/
				SET Command=Lecho "%%t !LAST_VAR_SETTING_FAILURE_MSG:~1,-1!\n" /F

				!Command!
			)
		)
	)

	IF /I "!DISABLE_BOOT_DEVICES!" == "1" (

		IF /I NOT "!DISABLE_BOOT_PRIM_DEVICE!" == "Unset" (

			IF /I NOT "!DISABLE_BOOT_PRIM_DEVICE!" == "prim" (

				REM /*--- Increment error counter. ---*/
				SET /A ERROR_COUNT+=1

				REM /*--- Set the last variable setting failure error message. ---*/
				SET LAST_VAR_SETTING_FAILURE_MSG="<<< [ %0 ] - ERROR: Invalid value for TK_FIBRE_!HBA_NUMBER!_BOOT_DISABLE.  Valid values are: All, prim, alt1, alt2, and/or alt3. >>>"

				REM /*--- Let's set the message to be returned. ---*/
				SET Command=Lecho "%%t !LAST_VAR_SETTING_FAILURE_MSG:~1,-1!\n" /F

				!Command!
			)
		)

		IF /I NOT "!DISABLE_BOOT_ALT1_DEVICE!" == "Unset" (

			IF /I NOT "!DISABLE_BOOT_ALT1_DEVICE!" == "alt1" (

				REM /*--- Increment error counter. ---*/
				SET /A ERROR_COUNT+=1

				REM /*--- Set the last variable setting failure error message. ---*/
				SET LAST_VAR_SETTING_FAILURE_MSG="<<< [ %0 ] - ERROR: Invalid value for TK_FIBRE_!HBA_NUMBER!_BOOT_DISABLE.  Valid values are: All, prim, alt1, alt2, and/or alt3. >>>"

				REM /*--- Let's set the message to be returned. ---*/
				SET Command=Lecho "%%t !LAST_VAR_SETTING_FAILURE_MSG:~1,-1!\n" /F

				!Command!
			)
		)

		IF /I NOT "!DISABLE_BOOT_ALT2_DEVICE!" == "Unset" (

			IF /I NOT "!DISABLE_BOOT_ALT2_DEVICE!" == "alt2" (

				REM /*--- Increment error counter. ---*/
				SET /A ERROR_COUNT+=1

				REM /*--- Set the last variable setting failure error message. ---*/
				SET LAST_VAR_SETTING_FAILURE_MSG="<<< [ %0 ] - ERROR: Invalid value for TK_FIBRE_!HBA_NUMBER!_BOOT_DISABLE.  Valid values are: All, prim, alt1, alt2, and/or alt3. >>>"

				REM /*--- Let's set the message to be returned. ---*/
				SET Command=Lecho "%%t !LAST_VAR_SETTING_FAILURE_MSG:~1,-1!\n" /F

				!Command!
			)
		)

		IF /I NOT "!DISABLE_BOOT_ALT3_DEVICE!" == "Unset" (

			IF /I NOT "!DISABLE_BOOT_ALT3_DEVICE!" == "alt3" (

				REM /*--- Increment error counter. ---*/
				SET /A ERROR_COUNT+=1

				REM /*--- Set the last variable setting failure error message. ---*/
				SET LAST_VAR_SETTING_FAILURE_MSG="<<< [ %0 ] - ERROR: Invalid value for TK_FIBRE_!HBA_NUMBER!_BOOT_DISABLE.  Valid values are: All, prim, alt1, alt2, and/or alt3. >>>"

				REM /*--- Let's set the message to be returned. ---*/
				SET Command=Lecho "%%t !LAST_VAR_SETTING_FAILURE_MSG:~1,-1!\n" /F

				!Command!
			)
		)
	)

IF NOT %HBA_NUMBER%==%NUMBER_OF_HBAS_TO_CONFIGURE% GOTO Loop

REM /*--- Let's check the number of errors found. ---*/
IF /I NOT "%ERROR_COUNT%" == "0" (

	REM /*--- Let's set the message to be returned. ---*/
	SET RMSG="<<< [ %0 ] - ERROR: Unable to pass the FIBRE prerequisite check.  Total errors detected: %ERROR_COUNT%.  Verify your variable settings are correct.  Last variable setting failure was '[!LAST_VAR_SETTING_FAILURE_MSG:~1,-1!]'. >>>"

	REM /*--- Let's set the command to be executed. ---*/
	SET Command=Lecho "\n%%t !RMSG:~1,-1!\n" /F

	!Command!

	GOTO Error_LD
)

REM * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *
REM *                               SUCCESS                                   *
REM * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *
:Success

Lecho "%%t " /F /SN
Lecho "[%0] " /F /SN /LO
Lecho "- FIBRE Prerequisites check completely successfully...\n" /F

ENDLOCAL

REM /*--- Set the return code to be returned. ---*/
SET RC=0

REM /*--- Set the message to be returned. ---*/
SET RMSG=[ %0 ] - FIBRE Prerequisites check completely successfully...

GOTO EndOfScript

REM * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *
REM *                           Error Handler                                 *
REM * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *
:Error

Call ErrorHandler %0

goto Error_E     
     
:Error_D

Call ErrorHandler %0 /Display

goto Error_E     

:Error_L

Call ErrorHandler %0 /Log

goto Error_E     

:Error_LD

ENDLOCAL

REM /*--- Set total errors detected. ---*/
SET ERROR_COUNT=%ERROR_COUNT%

REM /*--- Set last varaiable setting error detected. ---*/
SET LAST_VAR_SETTING_FAILURE_MSG=%LAST_VAR_SETTING_FAILURE_MSG%

REM /*--- Set the return code to be returned. ---*/
SET RC=1

REM /*--- Set the message to be returned. ---*/
SET RMSG=*** [ %0 ] - ERROR: Unable to pass the FIBRE prerequisite check.  Verify your variable settings are correct. ***
               
Call ErrorHandler %0 /Log /Display

:Error_E

REM * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *
REM *                         End Of Script                                   *
REM * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ *
:EndOfScript
